@@ -1,11 +1,10 @@
 /**************************************************************
- *** RHmm version 1.4.4                                     
+ *** RHmm version 1.5.0
  ***                                                         
  *** File: Hmm.h 
  ***                                                         
  *** Author: Ollivier TARAMASCO <Ollivier.Taramasco@imag.fr> 
  *** Author: Sebastian BAUER <sebastian.bauer@charite.de>
- *** Date: 2010/12/09                                     
  ***                                                         
  **************************************************************/
 
@@ -13,8 +12,6 @@
 #define _HMM_H_
 #pragma once
 
-#include "OTMathUtil.h"
-
 #ifdef _DEBOGAGE_
 #include "Debogage.h"
         #define MESS_CREAT(p){Rprintf("Creation de %s\n", (p)) ;}
