@@ -1,11 +1,10 @@
 /**************************************************************
- *** RHmm version 1.4.4                                     
+ *** RHmm version 1.5.0
  ***                                                         
  *** File: MultivariateNormalUtil.h 
  ***                                                         
  *** Author: Ollivier TARAMASCO <Ollivier.Taramasco@imag.fr> 
  *** Author: Sebastian BAUER <sebastian.bauer@charite.de>
- *** Date: 2010/12/09                                     
  ***                                                         
  **************************************************************/
 
@@ -24,15 +23,6 @@
         #include <Rmath.h>
 #endif // _RDLL_
 
-#ifdef __SUNPRO_CC
-    #ifndef _RDLL_
-        #define log std::log
-        #define exp std::exp
-        #define fabs std::fabs
-        #define printf std::printf
-        #define sqrt std::sqrt
-    #endif // RDLL
-#endif //__SUNPRO_CC#endif __SUNPRO_CC
 
 #ifndef SQRT_TWO_PI
         #define SQRT_TWO_PI     2.5066282746310002
@@ -41,16 +31,10 @@
         typedef unsigned int uint ;
 #endif //int
 
-void SymetricInverseAndDet      (	cOTMatrix&      theMat,
-                                    double&         theDet,
-                                    cOTMatrix&      theInvMat
-                                ) ;
+void SymetricInverseAndDet(cDMatrix& theMat, double& theDet, cDMatrix& theInvMat) ;
 
-void MultivariateNormalDensity  (   cOTVector&      thex,
-									cOTVector&      theMu,
-                                    cOTMatrix&      theInvCov,
-                                    double          theDet,
-                                    double*         theDens
-                                ) ;
+void MultivariateNormalDensity(cDVector& thex, cDVector& theMu, cDMatrix& theInvCov, double theDet, double* theDens) ;
+
+void MultivariateNormalDensity(cDVector& thex, cDVector& theMu, cDMatrix& theInvCov, double theDet, cDVector& theDens) ;
 
 #endif //_MULTIVARIATENORMALUTIL_H_
