@@ -1,11 +1,10 @@
 /**************************************************************
- *** RHmm version 1.4.4                                     
+ *** RHmm version 1.5.0
  ***                                                         
  *** File: OTMathUtil.h 
  ***                                                         
  *** Author: Ollivier TARAMASCO <Ollivier.Taramasco@imag.fr> 
  *** Author: Sebastian BAUER <sebastian.bauer@charite.de>
- *** Date: 2010/12/09                                     
  ***                                                         
  **************************************************************/
 
@@ -14,6 +13,13 @@
 #pragma once
 
 #include "cOTError.h"
-#include "cOTVector.h"
-#include "cOTMatrix.h"
-#endif //_OTMATHUTIL_H_
+#include "cDVector.h"
+#include "cDMatrix.h"
+//typedef cDVector cDVector ;
+//typedef cDMatrix cDMatrix ;
+
+#define mSize GetSize()
+#define mNRow GetNRows()
+#define mNCol GetNCols()
+
+#endif // _OTMATHUTIL_H_
