@@ -1,11 +1,10 @@
 /**************************************************************
- *** RHmm version 1.4.4                                     
+ *** RHmm version 1.5.0
  ***                                                         
  *** File: cDiscrete.h 
  ***                                                         
  *** Author: Ollivier TARAMASCO <Ollivier.Taramasco@imag.fr> 
  *** Author: Sebastian BAUER <sebastian.bauer@charite.de>
- *** Date: 2010/12/09                                     
  ***                                                         
  **************************************************************/
 
@@ -18,18 +17,18 @@ class cDiscrete : public cDistribution
 {       private :
                 uint            mvNClass        ;
         public :
-                cOTVector*      mProba          ;
+                cCyclicVector<cDMatrix>        mProbaMatVector;
         public :
                 cDiscrete(uint theNClass, uint theNProba) ;
                 virtual ~cDiscrete() ;
-                virtual void ComputeCondProba(cOTVector* theY, uint theNSample, cOTMatrix* theCondProba)  ;
-                virtual void UpdateParameters(cInParam& theInParam, cBaumWelch& theBaumWelch, cOTMatrix* theCondProba=NULL)  ;
+                virtual void ComputeCondProba(cDVector* theY, uint theNSample, cDMatrix* theCondProba)  ;
+                virtual void UpdateParameters(cInParam& theInParam, cBaumWelch& theBaumWelch, cDMatrix* theCondProba=NULL)  ;
                 virtual void InitParameters(cBaumWelchInParam &theInParam) ;
                 virtual void Print() ;
                 uint GetNProba() ;
-                virtual void GetParam(uint theDeb, cOTVector& theParam) ;
-                virtual void SetParam(uint theDeb, cOTVector& theParam) ;
-                uint GetNParam(void){ return mProba[0].mSize - 1 ; }
+                virtual void GetParam(uint theDeb, cDVector& theParam) ;
+                virtual void SetParam(uint theDeb, cDVector& theParam) ;
+                uint GetNParam(void){ return mProbaMatVector[0].mNCol - 1 ; }
                 void CopyDistr(cDistribution *theSrc) ;
 } ;
 
