@@ -1,11 +1,10 @@
 /**************************************************************
- *** RHmm version 1.4.4                                     
+ *** RHmm version 1.5.0
  ***                                                         
  *** File: cMixtUnivariateNormal.h 
  ***                                                         
  *** Author: Ollivier TARAMASCO <Ollivier.Taramasco@imag.fr> 
  *** Author: Sebastian BAUER <sebastian.bauer@charite.de>
- *** Date: 2010/12/09                                     
  ***                                                         
  **************************************************************/
 
@@ -20,19 +19,19 @@ class cMixtUnivariateNormal : public cDistribution
                 uint    mvNClass        ;
                 uint    mvNMixt         ;
         public :
-                cOTVector*      mMean   ;
-                cOTVector*      mVar    ;
-                cOTVector*      mp              ;
+                cDVector*      mMean   ;
+                cDVector*      mVar    ;
+                cDVector*      mp              ;
         public :
                 cMixtUnivariateNormal(uint theNClass = 0, uint theNMixt = 1) ;
                 virtual ~cMixtUnivariateNormal() ;
-                virtual void ComputeCondProba(cOTVector* theY, uint theNSample, cOTMatrix* theCondProba)  ;
-                virtual void UpdateParameters(cInParam& theInParam, cBaumWelch& theBaumWelch, cOTMatrix* theCondProba=NULL)  ;
+                virtual void ComputeCondProba(cDVector* theY, uint theNSample, cDMatrix* theCondProba)  ;
+                virtual void UpdateParameters(cInParam& theInParam, cBaumWelch& theBaumWelch, cDMatrix* theCondProba=NULL)  ;
                 virtual void InitParameters(cBaumWelchInParam &theInParam) ;
                 virtual void Print() ;
                 virtual void CopyDistr(cDistribution *theSrc) ;
-                virtual void GetParam(uint theDeb, cOTVector& theParam) ;
-                virtual void SetParam(uint theDeb, cOTVector& theParam) ;
+                virtual void GetParam(uint theDeb, cDVector& theParam) ;
+                virtual void SetParam(uint theDeb, cDVector& theParam) ;
                 uint GetNParam(void){ return mvNMixt * 3 - 1  ; }
 } ;
 #endif //_CMIXTUNIVARIATENORMAL_H_
