@@ -1,11 +1,10 @@
 /**************************************************************
- *** RHmm version 1.4.4                                     
+ *** RHmm version 1.5.0
  ***                                                         
  *** File: cMultivariateNormal.h 
  ***                                                         
  *** Author: Ollivier TARAMASCO <Ollivier.Taramasco@imag.fr> 
  *** Author: Sebastian BAUER <sebastian.bauer@charite.de>
- *** Date: 2010/12/09                                     
  ***                                                         
  **************************************************************/
 
@@ -20,17 +19,17 @@ class cMultivariateNormal : public cDistribution
 {       private :
                 uint    mvNClass        ;
         public :
-                cOTVector*      mMean   ;
-                cOTMatrix*      mCov    ;
+                cDVector*      mMean   ;
+                cDMatrix*      mCov    ;
         public :
                 cMultivariateNormal(uint theNClass = 0, uint theDimObs = 1) ;
                 virtual ~cMultivariateNormal() ;
-                virtual void ComputeCondProba(cOTVector* theY, uint theNSample, cOTMatrix* theCondProba) ;
-                virtual void UpdateParameters(cInParam& theInParam, cBaumWelch& theBaumWelch, cOTMatrix* theCondProba=NULL) ;
+                virtual void ComputeCondProba(cDVector* theY, uint theNSample, cDMatrix* theCondProba) ;
+                virtual void UpdateParameters(cInParam& theInParam, cBaumWelch& theBaumWelch, cDMatrix* theCondProba=NULL) ;
                 virtual void InitParameters(cBaumWelchInParam &theInParam) ;
                 virtual void Print() ;
-                virtual void GetParam(uint theDeb, cOTVector& theParam) ;
-                virtual void SetParam(uint theDeb, cOTVector& theParam) ;
+                virtual void GetParam(uint theDeb, cDVector& theParam) ;
+                virtual void SetParam(uint theDeb, cDVector& theParam) ;
                 uint GetDimObs() ;
                 void CopyDistr(cDistribution* theSrc) ;
                 uint GetNParam(void){ return mMean[0].mSize + mMean[0].mSize * mMean[0].mSize ; }
